@@ -5,7 +5,7 @@
 #' Plot biomass, recruitment, and fishing mortality time series from several . This function can be used to compare outputs among
 #' different assessment models from the same Data object.
 #'
-#' @param ... Objects of class \linkS4class{Assessment}.
+#' @param ... Objects of class [Assessment-class].
 #' @param label A character vector of the models for the legend.
 #' @param color A vector of colors for each assessment model.
 #' @author Q. Huynh
@@ -124,10 +124,10 @@ report <- function(Assessment, retro = NULL, filename = paste0("report_", Assess
   filename_rmd <- paste0(filename, ".Rmd")
 
   if (!dir.exists(dir)) {
-    message("Creating directory: \n", dir)
+    message_info("Creating directory: \n", dir)
     dir.create(dir)
   }
-  message("Writing markdown file: ", file.path(dir, filename_rmd))
+  message_info("Writing markdown file: ", file.path(dir, filename_rmd))
 
   if (Assessment@Model == "SCA2") Assessment@info$data$SR_type <- Assessment@info$SR
   dots <- list(...)
@@ -152,10 +152,10 @@ report <- function(Assessment, retro = NULL, filename = paste0("report_", Assess
   }
   render_args$quiet <- quiet
 
-  message("Rendering markdown file: ", file.path(dir, filename_rmd))
+  message_info("Rendering markdown file: ", file.path(dir, filename_rmd))
+  message_info("See help(plot.Assessment) to adjust report and file directory.")
   output_filename <- do.call(rmarkdown::render, render_args)
   message("Rendered file: ", output_filename)
-  message("See help(plot.Assessment) to adjust report and file directory.")
 
   if (open_file) browseURL(output_filename)
   invisible(output_filename)
@@ -182,7 +182,7 @@ report <- function(Assessment, retro = NULL, filename = paste0("report_", Assess
 #' and standard deviations are provided.
 #' @author Q. Huynh
 #' @export plot_lognormalvar
-#' @seealso \code{\link{plot_betavar}} \code{\link{plot_steepness}}
+#' @seealso [plot_betavar()] [plot_steepness()]
 #' @examples
 #' mu <- 0.5
 #' stddev <- 0.1
@@ -316,7 +316,7 @@ plot_normalvar <- function(m, sd, label = NULL, color = "black") {
 #' and standard deviations are provided.
 #' @author Q. Huynh
 #' @export plot_betavar
-#' @seealso \code{\link{plot_lognormalvar}} \code{\link{plot_steepness}}
+#' @seealso [plot_lognormalvar()] [plot_steepness()]
 #' @examples
 #' mu <- 0.5
 #' stddev <- 0.1
@@ -385,7 +385,7 @@ plot_betavar <- function(m, sd, label = NULL, is_logit = FALSE, color = "black")
 #' transformed from 0 - 1 to 0.2 - 1.
 #' @author Q. Huynh
 #' @export
-#' @seealso \code{\link{plot_lognormalvar}} \code{\link{plot_betavar}}
+#' @seealso [plot_lognormalvar()] [plot_betavar()]
 #' @examples
 #' mu <- 0.8
 #' stddev <- 0.1
@@ -494,15 +494,15 @@ plot_steepness <- function(m, sd, is_transform = FALSE, SR = c("BH", "Ricker"),
 #' @param obs A vector of observed data.
 #' @param fit A vector of predicted data (e.g., from an assessment model).
 #' @param obs_CV A vector of year-specific coefficient of variation in the observed data.
-#' @param obs_CV_CI The confidence interval for the error bars based for \code{obs_CV}.
-#' @param obs_upper A vector of year-specific upper bounds for the error bars of the observed data (in lieu of argument \code{obs_CV}).
-#' @param obs_lower A vector of year-specific lower bounds for the error bars of the observed data (in lieu of argument \code{obs_CV}).
-#' @param obs_ind_blue Indices of \code{obs} for which the plotted points and error bars will be blue.
-#' @param fit_linewidth Argument \code{lwd} for fitted line.
+#' @param obs_CV_CI The confidence interval for the error bars based for `obs_CV`.
+#' @param obs_upper A vector of year-specific upper bounds for the error bars of the observed data (in lieu of argument `obs_CV`).
+#' @param obs_lower A vector of year-specific lower bounds for the error bars of the observed data (in lieu of argument `obs_CV`).
+#' @param obs_ind_blue Indices of `obs` for which the plotted points and error bars will be blue.
+#' @param fit_linewidth Argument `lwd` for fitted line.
 #' @param fit_color Color of fitted line.
 #' @param label Character string that describes the data to label the y-axis.
 #' @author Q. Huynh
-#' @seealso \code{\link{plot_residuals}}
+#' @seealso [plot_residuals()]
 #' @return A plot of annual observed data and predicted values from a model.
 #' @examples
 #' data(Red_snapper)
@@ -560,16 +560,16 @@ plot_timeseries <- function(Year, obs, fit = NULL, obs_CV = NULL, obs_CV_CI = 0.
 #'
 #' @param Year A vector of years for the data.
 #' @param res A vector of residuals.
-#' @param res_sd A vector of year specific standard deviation for \code{res}.
-#' @param res_sd_CI The confidence interval for the error bars based for \code{res_sd}.
-#' @param res_upper A vector of year-specific upper bounds for the error bars of the residual (in lieu of argument \code{res_CV}).
-#' @param res_lower A vector of year-specific lower bounds for the error bars of the residual (in lieu of argument \code{res_CV}).
-#' @param res_ind_blue Indices of \code{obs} for which the plotted residuals and error bars will be blue.
+#' @param res_sd A vector of year specific standard deviation for `res`.
+#' @param res_sd_CI The confidence interval for the error bars based for `res_sd`.
+#' @param res_upper A vector of year-specific upper bounds for the error bars of the residual (in lieu of argument `res_CV`).
+#' @param res_lower A vector of year-specific lower bounds for the error bars of the residual (in lieu of argument `res_CV`).
+#' @param res_ind_blue Indices of `obs` for which the plotted residuals and error bars will be blue.
 #' @param draw_zero Indicates whether a horizontal line should be drawn at zero.
-#' @param zero_linetype Passes argument \code{lty} (e.g. solid line = 1, dotted = 2) to \code{draw_zero}.
+#' @param zero_linetype Passes argument `lty` (e.g. solid line = 1, dotted = 2) to `draw_zero`.
 #' @param label Character string that describes the data to label the y-axis.
 #' @author Q. Huynh
-#' @seealso \code{\link{plot_timeseries}}
+#' @seealso [plot_timeseries()]
 #' @return A plot of model residuals by year (optionally, with error bars).
 #' @export 
 plot_residuals <- function(Year, res, res_sd = NULL, res_sd_CI = 0.95,
@@ -628,20 +628,20 @@ plot_residuals <- function(Year, res, res_sd = NULL, res_sd_CI = 0.95,
 #' Same dimensions as obs.
 #' @param plot_type Indicates which plots to create. Options include annual distributions,
 #' bubble plot of the data, and bubble plot of the Pearson residuals, and annual means.
-#' @param N Annual sample sizes. Vector of length \code{nrow(obs)}.
-#' @param CAL_bins A vector of lengths corresponding to the columns in \code{obs}.
-#' and \code{fit}. Ignored for age data.
-#' @param ages An optional vector of ages corresponding to the columns in \code{obs}.
-#' @param ind A numeric vector for plotting a subset of rows (which indexes year) of \code{obs} and \code{fit}.
-#' @param annual_ylab Character string for y-axis label when \code{plot_type = "annual"}.
-#' @param annual_yscale For annual composition plots (\code{plot_type = "annual"}), whether the raw values
+#' @param N Annual sample sizes. Vector of length `nrow(obs)`.
+#' @param CAL_bins A vector of lengths corresponding to the columns in `obs`.
+#' and `fit`. Ignored for age data.
+#' @param ages An optional vector of ages corresponding to the columns in `obs`.
+#' @param ind A numeric vector for plotting a subset of rows (which indexes year) of `obs` and `fit`.
+#' @param annual_ylab Character string for y-axis label when `plot_type = "annual"`.
+#' @param annual_yscale For annual composition plots (`plot_type = "annual"`), whether the raw values
 #' ("raw") or frequencies ("proportions") are plotted.
 #' @param bubble_adj Numeric, for adjusting the relative size of bubbles in bubble plots
 #' (larger number = larger bubbles).
-#' @param fit_linewidth Argument \code{lwd} for fitted line.
+#' @param fit_linewidth Argument `lwd` for fitted line.
 #' @param fit_color Color of fitted line.
 #' @param bubble_color Colors for negative and positive residuals, respectively, for bubble plots.
-#' @return Plots depending on \code{plot_type}. Invisibly returns a matrix or list of values that were plotted.
+#' @return Plots depending on `plot_type`. Invisibly returns a matrix or list of values that were plotted.
 #' @author Q. Huynh
 #' @export
 #' @examples
@@ -926,15 +926,15 @@ plot_Kobe <- function(biomass, exploit, arrow_size = 0.07, color = TRUE, xlab =
 #'
 #' @param Spawners A vector of the number of the spawners (x-axis).
 #' @param expectedR A vector of the expected recruitment (from the
-#' stock-recruit function) corresponding to values of \code{Spawners}.
+#' stock-recruit function) corresponding to values of `Spawners`.
 #' @param R0 Virgin recruitment.
 #' @param S0 Virgin spawners.
 #' @param rec_dev If recruitment deviations are estimated, a vector of estimated recruitment
-#' (in normal space) corresponding to values of \code{Spawners}.
+#' (in normal space) corresponding to values of `Spawners`.
 #' @param trajectory Indicates whether arrows will be drawn showing the trajectory of
 #' spawners and recruitment deviations over time.
 #' @param y_zoom If recruitment deviations are plotted, the y-axis limit relative to
-#' maximum expected recruitment \code{expectedR}. If \code{NULL}, all recruitment values are plotted.
+#' maximum expected recruitment `expectedR`. If `NULL`, all recruitment values are plotted.
 #' @param ylab Character string for label on y-axis.
 #' @author Q. Huynh
 #' @return A stock-recruit plot
